@@ -10,6 +10,7 @@
 package org.gnu.gnome;
 import org.gnu.gdk.Bitmap;
 import org.gnu.gdk.Color;
+import org.gnu.glib.Handle;
 import org.gnu.glib.Type;
 
 /**
@@ -26,7 +27,7 @@ public class CanvasEllipse extends CanvasRE {
 	 * Constructs an instance of CanvasEllipse from a native widget resource.
 	 * @param handle The handle to the native widget.
 	 */
-	CanvasEllipse(int handle) {
+	CanvasEllipse(Handle handle) {
 		super(handle);
 	}
 
@@ -47,9 +48,9 @@ public class CanvasEllipse extends CanvasRE {
 	public CanvasEllipse(CanvasGroup group, double x1, double y1, double x2, double y2, Color fill_color, Color outline_color, Bitmap fill_stipple, Bitmap outline_stipple, int width_pixels) {
 		super(gnome_canvas_re_new_gdk_wpix(group.getHandle(), gnome_canvas_ellipse_get_type(),
 				x1, y1, x2, y2, fill_color.getHandle(),
-				outline_color == null ? 0 : outline_color.getHandle(),
-				fill_stipple == null ? 0 : fill_stipple.getHandle(),
-				outline_stipple == null ? 0 : outline_stipple.getHandle(),
+				outline_color == null ? null : outline_color.getHandle(),
+				fill_stipple == null ? null : fill_stipple.getHandle(),
+				outline_stipple == null ? null : outline_stipple.getHandle(),
 				width_pixels));
 	}
 
@@ -69,9 +70,9 @@ public class CanvasEllipse extends CanvasRE {
 	public CanvasEllipse(CanvasGroup group, double x1, double y1, double x2, double y2, Color fill_color, Color outline_color, Bitmap fill_stipple, Bitmap outline_stipple, double width_units) {
 		super(gnome_canvas_re_new_gdk_wunit(group.getHandle(), gnome_canvas_ellipse_get_type(),
 				x1, y1, x2, y2, fill_color.getHandle(),
-				outline_color == null ? 0 : outline_color.getHandle(),
-				fill_stipple == null ? 0 : fill_stipple.getHandle(),
-				outline_stipple == null ? 0 : outline_stipple.getHandle(),
+				outline_color == null ? null : outline_color.getHandle(),
+				fill_stipple == null ? null : fill_stipple.getHandle(),
+				outline_stipple == null ? null : outline_stipple.getHandle(),
 				width_units));
 	}
 
@@ -113,11 +114,7 @@ public class CanvasEllipse extends CanvasRE {
 		return new Type(gnome_canvas_ellipse_get_type());
 	}
 
-	/****************************************
-	 * BEGINNING OF GENERATED CODE
-	 ****************************************/
+
 	native static final protected int gnome_canvas_ellipse_get_type();
-	/****************************************
-	 * END OF GENERATED CODE
-	 ****************************************/
+
 }
